Periodicity
===========

Several methods for analyzing periodicity are included.

Autocorrelation
---------------

Autocorrelation is plotted using :meth:`pandas.plotting.autocorrelation_plot`.

.. autofunction:: traja.plotting.plot_autocorrelation

Periodogram (Power Spectum)
---------------------------

Convenience wrapper for :meth:`scipy.signal.periodogram`.

.. autofunction:: traja.plotting.plot_periodogram